@@ -2,6 +2,7 @@ package Eixo::Rest::Client;
 use strict;
 
 use Eixo::Base::Clase;
+
 use URI;
 use LWP::UserAgent;
 use LWP::Protocol::https;
@@ -146,8 +147,12 @@ sub post: Log {
     }
     else{
         
+        # application/x-www-form-urlencoded
         # raw stream
-        $content = $args{POST_DATA};
+        while(my ($key, $value) = each (%{$args{POST_DATA} || {}})){
+            $content .= "$key=$value&";
+        }
+
     }
 
     $req->content($content);
@@ -206,8 +211,12 @@ sub put: Log {
     }
     else{
         
+        # application/x-www-form-urlencoded
         # raw stream
-        $content = $args{POST_DATA};
+        while(my ($key, $value) = each (%{$args{POST_DATA} || {}})){
+            $content .= "$key=$value&";
+        }
+
 
     }
 
